@@ -7,7 +7,7 @@
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information
 
 project = "CP2K"
-copyright = "2000-2024, CP2K Developers"
+copyright = "2000-2025, CP2K Developers"
 author = "CP2K Developers"
 
 # -- General configuration ---------------------------------------------------
@@ -16,9 +16,11 @@ author = "CP2K Developers"
 extensions = [
     "myst_parser",
     "sphinx_rtd_theme",
+    "sphinx_reredirects",
     "sphinx.ext.mathjax",
     "sphinx.ext.intersphinx",
     "sphinxcontrib.youtube",
+    "sphinxcontrib.mermaid",
 ]
 
 myst_enable_extensions = [
@@ -28,6 +30,8 @@ myst_enable_extensions = [
     "strikethrough",
 ]
 
+myst_fence_as_directive = ["mermaid"]
+
 templates_path = ["_templates"]
 exclude_patterns = ["_build", "Thumbs.db", ".DS_Store", "README.md"]
 
@@ -59,4 +63,9 @@ html_theme_options = {
     "collapse_navigation": False,
 }
 
+redirects = {
+    "getting-started/CMake": "build-from-source.html",
+    "getting-started/spack": "build-with-spack.html",
+}
+
 # EOF
