@@ -1,6 +1,6 @@
 /*----------------------------------------------------------------------------*/
 /*  CP2K: A general program to perform molecular dynamics simulations         */
-/*  Copyright 2000-2024 CP2K developers group <https://cp2k.org>              */
+/*  Copyright 2000-2025 CP2K developers group <https://cp2k.org>              */
 /*                                                                            */
 /*  SPDX-License-Identifier: BSD-3-Clause                                     */
 /*----------------------------------------------------------------------------*/
@@ -54,6 +54,7 @@ static void hashtable_init(dbm_shard_t *shard) {
   shard->hashtable_mask = shard->hashtable_size - 1;
   shard->hashtable_prime = next_prime(shard->hashtable_size);
   shard->hashtable = calloc(shard->hashtable_size, sizeof(int));
+  assert(shard->hashtable != NULL);
 }
 
 /*******************************************************************************
@@ -64,11 +65,13 @@ void dbm_shard_init(dbm_shard_t *shard) {
   shard->nblocks = 0;
   shard->nblocks_allocated = INITIAL_NBLOCKS_ALLOCATED;
   shard->blocks = malloc(shard->nblocks_allocated * sizeof(dbm_block_t));
+  assert(shard->blocks != NULL);
   hashtable_init(shard);
   shard->data_size = 0;
   shard->data_promised = 0;
   shard->data_allocated = INITIAL_DATA_ALLOCATED;
   shard->data = malloc(shard->data_allocated * sizeof(double));
+  assert(shard->data != NULL);
 
   omp_init_lock(&shard->lock);
 }
@@ -82,6 +85,7 @@ void dbm_shard_copy(dbm_shard_t *shard_a, const dbm_shard_t *shard_b) {
   shard_a->nblocks = shard_b->nblocks;
   shard_a->nblocks_allocated = shard_b->nblocks_allocated;
   shard_a->blocks = malloc(shard_b->nblocks_allocated * sizeof(dbm_block_t));
+  assert(shard_a->blocks != NULL);
   memcpy(shard_a->blocks, shard_b->blocks,
          shard_b->nblocks * sizeof(dbm_block_t));
 
@@ -90,12 +94,14 @@ void dbm_shard_copy(dbm_shard_t *shard_a, const dbm_shard_t *shard_b) {
   shard_a->hashtable_mask = shard_b->hashtable_mask;
   shard_a->hashtable_prime = shard_b->hashtable_prime;
   shard_a->hashtable = malloc(shard_b->hashtable_size * sizeof(int));
+  assert(shard_a->hashtable != NULL);
   memcpy(shard_a->hashtable, shard_b->hashtable,
          shard_b->hashtable_size * sizeof(int));
 
   free(shard_a->data);
   shard_a->data_allocated = shard_b->data_allocated;
   shard_a->data = malloc(shard_b->data_allocated * sizeof(double));
+  assert(shard_a->data != NULL);
   shard_a->data_size = shard_b->data_size;
   memcpy(shard_a->data, shard_b->data, shard_b->data_size * sizeof(double));
 }
@@ -173,8 +179,9 @@ dbm_block_t *dbm_shard_promise_new_block(dbm_shard_t *shard, const int row,
   // Grow blocks array if necessary.
   if (shard->nblocks_allocated < shard->nblocks + 1) {
     shard->nblocks_allocated = ALLOCATION_FACTOR * (shard->nblocks + 1);
-    shard->blocks = (dbm_block_t *)realloc(
-        shard->blocks, shard->nblocks_allocated * sizeof(dbm_block_t));
+    shard->blocks =
+        realloc(shard->blocks, shard->nblocks_allocated * sizeof(dbm_block_t));
+    assert(shard->blocks != NULL);
 
     // rebuild hashtable
     free(shard->hashtable);
@@ -205,8 +212,8 @@ void dbm_shard_allocate_promised_blocks(dbm_shard_t *shard) {
   // Reallocate data array if necessary.
   if (shard->data_promised > shard->data_allocated) {
     shard->data_allocated = ALLOCATION_FACTOR * shard->data_promised;
-    shard->data =
-        (double *)realloc(shard->data, shard->data_allocated * sizeof(double));
+    shard->data = realloc(shard->data, shard->data_allocated * sizeof(double));
+    assert(shard->data != NULL);
   }
 
   // Zero new blocks.
