@@ -1,6 +1,6 @@
 /*----------------------------------------------------------------------------*/
 /*  CP2K: A general program to perform molecular dynamics simulations         */
-/*  Copyright 2000-2024 CP2K developers group <https://cp2k.org>              */
+/*  Copyright 2000-2025 CP2K developers group <https://cp2k.org>              */
 /*                                                                            */
 /*  SPDX-License-Identifier: BSD-3-Clause                                     */
 /*----------------------------------------------------------------------------*/
@@ -10,7 +10,8 @@
 #define GRID_STRINGIFY(SYMBOL) #SYMBOL
 
 // GCC added the simd pragma with version 6.
-#if defined(__GNUC__) && !defined(__INTEL_COMPILER) && __GNUC__ < 6
+#if defined(__GNUC__) && !defined(__INTEL_COMPILER) &&                         \
+    !defined(__INTEL_LLVM_COMPILER) && __GNUC__ < 6
 #define GRID_PRAGMA_SIMD(OBJS, N)
 // Intel added the simd pragma with version 19.00.
 #elif defined(__INTEL_COMPILER) && __INTEL_COMPILER < 1900
@@ -22,11 +23,13 @@
 #endif
 
 // GCC added the unroll pragma with version 8 and...
-#if defined(__GNUC__) && !defined(__INTEL_COMPILER) && __GNUC__ < 8
+#if defined(__GNUC__) && !defined(__INTEL_COMPILER) &&                         \
+    !defined(__INTEL_LLVM_COMPILER) && __GNUC__ < 8
 #define GRID_PRAGMA_UNROLL(N)
 #define GRID_PRAGMA_UNROLL_UP_TO(N)
 // ...chose a custom syntax.
-#elif defined(__GNUC__) && !defined(__INTEL_COMPILER) && __GNUC__ >= 8
+#elif defined(__GNUC__) && !defined(__INTEL_COMPILER) &&                       \
+    !defined(__INTEL_LLVM_COMPILER) && __GNUC__ >= 8
 #define GRID_PRAGMA_UNROLL(N) _Pragma(GRID_STRINGIFY(GCC unroll N))
 #define GRID_PRAGMA_UNROLL_UP_TO(N) _Pragma(GRID_STRINGIFY(GCC unroll N))
 // Most other compilers support a common syntax.
