@@ -2,11 +2,12 @@
 
 # author: Ole Schuett
 
-from asyncio import Semaphore
+from asyncio import Semaphore, Task
 from asyncio.subprocess import DEVNULL, PIPE, STDOUT, Process
 from datetime import datetime
 from pathlib import Path
 from typing import Any, Coroutine, Dict, List, Optional, TextIO, Tuple, Union
+from statistics import mean, stdev
 import argparse
 import asyncio
 import math
@@ -42,10 +43,6 @@ KEEPALIVE_SKIP_DIRS = [
 ]
 
 
-def cp2k_stem() -> str:
-    return os.getenv("CP2K_STEM", "cp2k")
-
-
 # ======================================================================================
 async def main() -> None:
     parser = argparse.ArgumentParser(description="Runs CP2K regression test suite.")
@@ -71,7 +68,7 @@ async def main() -> None:
     parser.add_argument("--workbasedir", type=Path)
     parser.add_argument("--skip_unittests", action="store_true")
     parser.add_argument("--skip_regtests", action="store_true")
-    parser.add_argument("arch")
+    parser.add_argument("binary_dir", type=Path)
     parser.add_argument("version")
     cfg = Config(parser.parse_args())
 
@@ -79,9 +76,7 @@ async def main() -> None:
     start_time = time.perf_counter()
 
     # Query CP2K binary for feature flags.
-    version_bytes, _ = await (
-        await cfg.launch_exe(cp2k_stem(), "--version")
-    ).communicate()
+    version_bytes, _ = await (await cfg.launch_exe("cp2k", "--version")).communicate()
     version_output = version_bytes.decode("utf8", errors="replace")
     flags_line = re.search(r" cp2kflags:(.*)\n", version_output)
     if not flags_line:
@@ -103,7 +98,7 @@ async def main() -> None:
     print(f"Keepalive:      {cfg.keepalive}")
     print(f"Flag slow:      {cfg.flag_slow}")
     print(f"Debug:          {cfg.debug}")
-    print(f"ARCH:           {cfg.arch}")
+    print(f"Binary dir:     {cfg.binary_dir}")
     print(f"VERSION:        {cfg.version}")
     print(f"Flags:          " + ",".join(flags))
 
@@ -151,7 +146,7 @@ async def main() -> None:
         batches.append(batch)
 
     # Create async tasks.
-    tasks = []
+    tasks: List[Task[BatchResult]] = []
     num_restrictdirs = num_skipdirs = 0
     for batch in batches:
         if not batch.requirements_satisfied(flags, cfg.mpiranks):
@@ -199,26 +194,29 @@ async def main() -> None:
     timings = sorted(r.duration for r in all_results)
     print('Plot: name="timings", title="Timing Distribution", ylabel="time [s]"')
     for p in (100, 99, 98, 95, 90, 80):
-        v = percentile(timings, p / 100.0)
+        y = percentile(timings, p / 100.0)
         print(f'PlotPoint: name="{p}th_percentile", plot="timings", ', end="")
-        print(f'label="{p}th %ile", y={v:.2f}, yerr=0.0')
+        print(f'label="{p}th %ile", y={y:.2f}, yerr=0.0')
 
     if cfg.flag_slow:
         print("\n" + "-" * 15 + "--------------- Slow Tests ---------------" + "-" * 15)
-        slow_test_threshold = 2 * percentile(timings, 0.95)
-        maybe_slow = [r for r in all_results if r.duration > slow_test_threshold]
-        suppressions = cfg.slow_suppressions
-        slow_reruns: List[str] = []
-        for batch in {r.batch for r in maybe_slow if r.fullname not in suppressions}:
-            print(f"Re-running {batch.name} to avoid false positives.")
-            res = (await run_batch(batch, cfg)).results
-            slow_reruns += [r.fullname for r in res if r.duration > slow_test_threshold]
-        slow_tests = [r for r in maybe_slow if r.fullname in slow_reruns]
-        num_suppressed = len([r for r in maybe_slow if r.fullname in suppressions])
-        print(f"Duration threshold (2x 95th %ile): {slow_test_threshold:.2f} sec")
+        threshold = 2 * percentile(timings, 0.95)
+        outliers = [r for r in all_results if r.duration > threshold]
+        maybe_slow = [r for r in outliers if r.fullname not in cfg.slow_suppressions]
+        num_suppressed = len(outliers) - len(maybe_slow)
+        rerun_tasks: List[Task[BatchResult]] = []
+        for b in {r.batch for r in maybe_slow}:
+            print(f"Re-running {b.name} to avoid false positives.")
+            rerun_tasks.append(asyncio.get_event_loop().create_task(run_batch(b, cfg)))
+        rerun_times: Dict[str, float] = {}
+        for t in await asyncio.gather(*rerun_tasks):
+            rerun_times.update({r.fullname: r.duration for r in t.results})
+        stats = {r.fullname: [r.duration, rerun_times[r.fullname]] for r in maybe_slow}
+        slow_tests = {k: v for k, v in stats.items() if mean(v) > threshold}
+        print(f"Duration threshold (2x 95th %ile): {threshold:.2f} sec")
         print(f"Found {len(slow_tests)} slow tests ({num_suppressed} suppressed):")
-        for r in slow_tests:
-            print(f"    {r.fullname :<80s} ( {r.duration:6.2f} sec)")
+        for k, v in slow_tests.items():
+            print(f"    {k :<80s} ( {mean(v):6.2f} ±{stdev(v):4.2f} sec)")
 
     print("\n------------------------------- Summary --------------------------------")
     total_duration = time.perf_counter() - start_time
@@ -252,7 +250,7 @@ class Config:
         default_ompthreads = 2 if "smp" in args.version else 1
         self.ompthreads = args.ompthreads if args.ompthreads else default_ompthreads
         self.mpiranks = args.mpiranks if self.use_mpi else 1
-        self.num_workers = int(args.maxtasks / self.ompthreads / self.mpiranks)
+        self.num_workers = int(args.maxtasks / self.ompthreads / self.mpiranks) or 1
         self.workers = Semaphore(self.num_workers)
         self.cp2k_root = Path(__file__).resolve().parent.parent
         self.mpiexec = args.mpiexec
@@ -262,7 +260,7 @@ class Config:
         self.valgrind = args.valgrind
         self.keepalive = args.keepalive
         self.flag_slow = args.flagslow
-        self.arch = args.arch
+        self.binary_dir = args.binary_dir.resolve()
         self.version = args.version
         self.debug = args.debug
         self.max_errors = args.maxerrors
@@ -271,12 +269,8 @@ class Config:
         self.skip_unittests = args.skip_unittests
         self.skip_regtests = args.skip_regtests
         datestamp = datetime.now().strftime("%Y-%m-%d_%H-%M-%S")
-        leaf_dir = f"TEST-{args.arch}-{args.version}-{datestamp}"
-        self.work_base_dir = (
-            args.workbasedir / leaf_dir
-            if args.workbasedir
-            else self.cp2k_root / "regtesting" / args.arch / args.version / leaf_dir
-        )
+        leaf_dir = f"TEST-{datestamp}"
+        self.work_base_dir = (args.workbasedir or args.binary_dir).resolve() / leaf_dir
         self.error_summary = self.work_base_dir / "error_summary"
 
         # Parse suppression files.
@@ -312,13 +306,11 @@ class Config:
             env["CUDA_VISIBLE_DEVICES"] = ",".join(visible_gpu_devices)
             env["HIP_VISIBLE_DEVICES"] = ",".join(visible_gpu_devices)
         env["OMP_NUM_THREADS"] = str(self.ompthreads)
-        exe_path = Path(f"{exe_stem}.{self.version}")
-        if exe_path.is_absolute():
-            cmd = [str(exe_path)]
-        else:
-            cmd = [
-                str(self.cp2k_root / "exe" / self.arch / f"{exe_stem}.{self.version}")
-            ]
+        env["PIKA_COMMANDLINE_OPTIONS"] = (
+            f"--pika:bind=none --pika:threads={self.ompthreads}"
+        )
+        exe_name = f"{exe_stem}.{self.version}"
+        cmd = [str(self.binary_dir / exe_name)]
         if self.valgrind:
             cmd = ["valgrind", "--error-exitcode=42", "--exit-on-first-error=yes"] + cmd
         if self.use_mpi:
@@ -454,9 +446,7 @@ class Cp2kShell:
 
     async def start(self) -> None:
         assert self._child is None
-        self._child = await self.cfg.launch_exe(
-            cp2k_stem(), "--shell", cwd=self.workdir
-        )
+        self._child = await self.cfg.launch_exe("cp2k", "--shell", cwd=self.workdir)
         await self.ready()
         await self.sendline("HARSH")  # With harsh mode any error leads to an abort.
         await self.ready()
@@ -601,7 +591,7 @@ async def run_regtests_classic(batch: Batch, cfg: Config) -> List[TestResult]:
     for test in batch.regtests:
         start_time = time.perf_counter()
         start_dirsize = dirsize(batch.workdir)
-        child = await cfg.launch_exe(cp2k_stem(), test.inp_fn, cwd=batch.workdir)
+        child = await cfg.launch_exe("cp2k", test.inp_fn, cwd=batch.workdir)
         output, returncode, timed_out = await wait_for_child_process(child, cfg.timeout)
         test.out_path.write_bytes(output)
         duration = time.perf_counter() - start_time
