@@ -33,17 +33,18 @@
 !-------------------------------------------------------------------------------
 MODULE cubecruncher
   IMPLICIT NONE
-  REAL, PARAMETER :: a2au = 1.0/0.5291772083 ! multiply angstrom by a2au to get bohr
+  INTEGER, PARAMETER :: dp = SELECTED_REAL_KIND ( 14, 200 )
+  REAL(KIND=dp), PARAMETER :: a2au = 1.0/0.5291772083 ! multiply angstrom by a2au to get bohr
   TYPE cube_type
      INTEGER :: npoints(3)
-     REAL, DIMENSION(:,:,:), POINTER :: grid
-     REAL    :: origin(3)
-     REAL    :: dh(3,3), h(3,3),  hinv(3,3)
+     REAL(KIND=dp), DIMENSION(:,:,:), POINTER :: grid
+     REAL(KIND=dp)    :: origin(3)
+     REAL(KIND=dp)    :: dh(3,3), h(3,3),  hinv(3,3)
      CHARACTER(LEN=80) :: title1,title2
      INTEGER :: Natom
-     REAL, DIMENSION(:,:), POINTER :: coords
+     REAL(KIND=dp), DIMENSION(:,:), POINTER :: coords
      INTEGER, DIMENSION(:), POINTER  :: Zatom
-     REAL, DIMENSION(:), POINTER :: auxfield
+     REAL(KIND=dp), DIMENSION(:), POINTER :: auxfield
   END TYPE cube_type
 
 CONTAINS
@@ -94,7 +95,7 @@ CONTAINS
     TYPE(cube_type), POINTER :: cube
     INTEGER                  :: iunit
     INTEGER                  :: stride
-    REAL                     :: mult_fact
+    REAL(KIND=dp)                     :: mult_fact
 
     INTEGER                  :: I1,I2,I3
 
@@ -125,7 +126,7 @@ CONTAINS
     INTEGER                  :: iunit
 
     INTEGER                  :: I1,I2,I3
-    REAL                     :: dum
+    REAL(KIND=dp)                     :: dum
 
     READ(iunit,'(A80)') cube%title1
     READ(iunit,'(A80)') cube%title2
@@ -159,7 +160,7 @@ CONTAINS
   END SUBROUTINE read_cube
 
 !-------------------------------------------------------------------------------
-! reads xyz into an existing cube type, overwriting the exising atomic data 
+! reads xyz into an existing cube type, overwriting the existing atomic data
 !-------------------------------------------------------------------------------
   SUBROUTINE read_xyz(cube,iunit)
     USE periodic_table, ONLY          : label2Z
@@ -193,11 +194,19 @@ CONTAINS
 
     TYPE(cube_type), POINTER :: cube
     integer :: i
-    real :: uvol, vol
+    REAL(KIND=dp) :: uvol, vol
+
+
+  write(*,*) cube%h(1,1), cube%h(2,1), cube%h(3,1)
+  write(*,*) cube%h(1,2), cube%h(2,2), cube%h(3,2)
+  write(*,*) cube%h(1,3), cube%h(2,3), cube%h(3,3)
 
     vol=cube%h(1,1)*(cube%h(2,2)*cube%h(3,3)-cube%h(2,3)*cube%h(3,2)) &
        -cube%h(2,1)*(cube%h(1,2)*cube%h(3,3)-cube%h(3,2)*cube%h(1,3)) &
        +cube%h(3,1)*(cube%h(1,2)*cube%h(2,3)-cube%h(2,2)*cube%h(1,3))
+
+    vol = ABS(vol)
+  write(*,*) vol
     IF(vol < 1.0E-10) stop
     uvol=1.d0/vol
     cube%hinv(1,1)= (cube%h(2,2)*cube%h(3,3)-cube%h(3,2)*cube%h(2,3))*uvol
@@ -215,9 +224,9 @@ CONTAINS
 function pbc(r,cube) result(r_pbc)
    
     TYPE(cube_type), POINTER :: cube
-    REAL, DIMENSION(3), INTENT(IN) :: r
-    REAL, DIMENSION(3) :: r_pbc
-    REAL, DIMENSION(3) :: s
+    REAL(KIND=dp), DIMENSION(3), INTENT(IN) :: r
+    REAL(KIND=dp), DIMENSION(3) :: r_pbc
+    REAL(KIND=dp), DIMENSION(3) :: s
 
     s=MATMUL(cube%hinv,r)
     s=s-ANINT(s)
@@ -230,12 +239,12 @@ end function pbc
 !-------------------------------------------------------------------------------
   SUBROUTINE center_cube(cube,center)
     TYPE(cube_type), POINTER :: cube
-    REAL, DIMENSION(3) :: center
+    REAL(KIND=dp), DIMENSION(3) :: center
 
     INTEGER                  :: I1,I2,I3,O1,O2,O3
     INTEGER, DIMENSION(3)    :: C
-    REAL :: h(3,3), hinv(3,3), uvol, vol, dvec(3)
-    REAL, DIMENSION(:,:,:), POINTER :: grid
+    REAL(KIND=dp) :: h(3,3), hinv(3,3), uvol, vol, dvec(3)
+    REAL(KIND=dp), DIMENSION(:,:,:), POINTER :: grid
     ALLOCATE(grid(cube%npoints(1),cube%npoints(2),cube%npoints(3)))
 
     ! notice h and hinv here correspond to dh and dhinv, do not overwrite cube%xxx fields with them
@@ -285,7 +294,7 @@ end function pbc
   END SUBROUTINE
 
 !-------------------------------------------------------------------------------
-! substract cubes, cube1=cube1-cube2
+! subtract cubes, cube1=cube1-cube2
 !-------------------------------------------------------------------------------
   SUBROUTINE subtract_cubes(cube1,cube2)
     TYPE(cube_type), POINTER :: cube1,cube2
@@ -304,12 +313,12 @@ end function pbc
 
     INTEGER                  :: i, I1,I2,closest
     INTEGER :: n1, n2, n3, no1, no2, no3
-    REAL, DIMENSION(3)       :: edges,center,displ
-    REAL                     :: d2, x,y,z
-    REAL :: h11h22,h11h33,h11h32,h11h23,h33h22,h31h22,h13h22,h31h13,h31h23,&
+    REAL(KIND=dp), DIMENSION(3)       :: edges,center,displ
+    REAL(KIND=dp)                     :: d2, x,y,z
+    REAL(KIND=dp) :: h11h22,h11h33,h11h32,h11h23,h33h22,h31h22,h13h22,h31h13,h31h23,&
            h12h21,h12h23,h12h31,h12h33,h32h21,h32h23,h32h13,h21h32,h21h33,&
            h21h13,h32h11h23,h12h23h31,h21h32h13,h11h22h33,h31h22h13,h21h12h33,deth
-    REAL, DIMENSION(3)       :: A, O, r, r_pbc
+    REAL(KIND=dp), DIMENSION(3)       :: A, O, r, r_pbc
 
     center(:)=cube%origin(:)+cube%h(:,1)/2.0 + cube%h(:,2)/2.0 + cube%h(:,3)/2.0
 
@@ -350,6 +359,7 @@ END MODULE cubecruncher
 ! uses the non-Fortran getarg / iargc
 !-------------------------------------------------------------------------------
 MODULE command_line_tools
+  USE cubecruncher, ONLY : dp
   TYPE input_type
     CHARACTER(LEN=200) :: cube_name_in
     CHARACTER(LEN=200) :: cube_name_out
@@ -359,8 +369,9 @@ MODULE command_line_tools
     LOGICAL :: do_xyz, do_center, do_fold, do_foldsmart,do_center_atom,do_center_geo, do_center_point
     LOGICAL :: have_input, have_output, write_help, write_version, do_subtract
     LOGICAL :: do_iso, do_slice, do_1d_profile, espot_over_iso, iso_current, have_espot_cube
+    LOGICAL :: from_top, check_atom_from_down
     INTEGER :: atom_center, stride, cube, index_profile
-    REAL    :: center_point(3), slice(3), iso_level(3), iso_hmin, iso_hmax, delta_profile,&
+    REAL(KIND=dp)    :: center_point(3), slice(3), iso_level(3), iso_hmin, iso_hmax, delta_profile,&
                 mult_fact, iso_delta_grid, bwidth
   END TYPE
 CONTAINS
@@ -386,6 +397,8 @@ CONTAINS
     input%iso_current = .FALSE.
     input%bwidth=2.0D0
     input%espot_over_iso = .FALSE.
+    input%from_top = .FALSE.
+    input%check_atom_from_down = .FALSE.
     input%index_profile=0
     input%delta_profile=0.0D0
     input%do_1d_profile=.FALSE.
@@ -524,10 +537,10 @@ CONTAINS
         input%iso_current = .TRUE.
         CALL getarg(I+1,nextarg)
         READ(nextarg,*) input%bwidth
-        WRITE(6,'(A,f10.5))') "Correct the iso-density surface to a better approx. of iso-current, W= ",input%bwidth
+        WRITE(6,'(A,f10.5)') "Correct the iso-density surface to a better approx. of iso-current, W= ",input%bwidth
       CASE("-espot")
         input%espot_over_iso=.TRUE.
-        WRITE(6,'(A))') "Assign the ES-pot values to the iso-surface"
+        WRITE(6,'(A)') "Assign the ES-pot values to the iso-surface"
       CASE("-espot_cube")
         input%have_espot_cube=.TRUE.
         CALL getarg(I+1,input%cube_name_espot)
@@ -536,6 +549,12 @@ CONTAINS
         CALL getarg(I+1,nextarg)
         READ(nextarg,*) input%iso_delta_grid
         WRITE(6,*) " Integration parameter to generate the 2D grid", input%iso_delta_grid
+      CASE("-iso_from_top")
+        input%from_top=.TRUE.
+        WRITE(6,*) " Search for the iso-current surface starting from top of the box "
+      CASE("-iso_stop_at_atom")
+        input%check_atom_from_down=.TRUE.
+        WRITE(6,*) " Does not allow the tip to go through atoms "
       CASE("-1d_profile")
         input%do_1d_profile=.TRUE.
         CALL getarg(I+1,nextarg)
@@ -573,9 +592,9 @@ MODULE cube_post_process
    USE cubecruncher
 
   IMPLICIT NONE
-!  REAL, PARAMETER :: a2au = 1.0/0.5291772083D0 ! multiply angstrom by a2au to get bohr
-  REAL, PARAMETER :: au2a = 0.5291772083D0 ! multiply bohr by au2a to get angstrom 
-  REAL, PARAMETER :: au2eV = 27.211384D0
+!  REAL(KIND=dp), PARAMETER :: a2au = 1.0/0.5291772083D0 ! multiply angstrom by a2au to get bohr
+  REAL(KIND=dp), PARAMETER :: au2a = 0.5291772083D0 ! multiply bohr by au2a to get angstrom 
+  REAL(KIND=dp), PARAMETER :: au2eV = 27.211384D0
 
 CONTAINS
 
@@ -583,12 +602,12 @@ CONTAINS
 
    TYPE(cube_type), POINTER :: cube
    INTEGER, INTENT(IN) :: index
-   REAL, INTENT(IN) :: delta
+   REAL(KIND=dp), INTENT(IN) :: delta
 
    CHARACTER(LEN=80) :: filename
    INTEGER :: i, ip_low, ip_up,j,k, ncount, np, npp
-   REAL,DIMENSION(:), ALLOCATABLE :: pos, av_val
-   REAL :: length, p, val, dh1, dh2
+   REAL(KIND=dp),DIMENSION(:), ALLOCATABLE :: pos, av_val
+   REAL(KIND=dp) :: length, p, val, dh1, dh2
 
    ALLOCATE(pos(cube%npoints(index)))
    ALLOCATE(av_val(cube%npoints(index)))
@@ -616,7 +635,7 @@ CONTAINS
            val =val + cube%grid(k,j,i)! *dh1*dh2
          END DO
        END DO
-       av_val(i) = val /REAL(ncount)
+       av_val(i) = val /REAL(ncount,KIND=dp)
      END DO
 
    ELSE IF(index==1) THEN
@@ -633,7 +652,7 @@ CONTAINS
            val =val + cube%grid(i,k,j)
          END DO
        END DO
-       av_val(i) = val/REAL(ncount)
+       av_val(i) = val/REAL(ncount,KIND=dp)
      END DO
 
    ELSE IF(index==2) THEN
@@ -650,7 +669,7 @@ CONTAINS
            val =val + cube%grid(k,i,j)
          END DO
        END DO
-       av_val(i) = val/REAL(ncount)
+       av_val(i) = val/REAL(ncount,KIND=dp)
      END DO
 
 
@@ -680,7 +699,7 @@ CONTAINS
      DO i =ip_low,ip_up
        val = val + av_val(i)
      END DO
-     val = val/REAL(ip_up-ip_low+1)
+     val = val/REAL(ip_up-ip_low+1,KIND=dp)
      WRITE(101,*) p, val
      IF(ip_up==cube%npoints(index)) EXIT
    END DO
@@ -694,12 +713,12 @@ CONTAINS
 
    TYPE(cube_type), POINTER :: cube
    INTEGER, INTENT(IN) ::dir 
-   REAL, INTENT(IN) :: height
+   REAL(KIND=dp), INTENT(IN) :: height
 
    CHARACTER(LEN=80) :: filename
    INTEGER :: index_plane, d1,d2
    INTEGER :: i, j,k
-   REAL :: r, r1, r2 , val
+   REAL(KIND=dp) :: r, r1, r2 , val
 
 
    d1=dir+1; if(d1>3) d1=1
@@ -709,9 +728,9 @@ CONTAINS
    END IF
 
    DO i = 1,cube%npoints(dir)
-      r=sqrt((real(i-1)*cube%dh(1,dir)-cube%origin(1))**2&
-               +(real(i-1)*cube%dh(2,dir)-cube%origin(2))**2+&
-                (real(i-1)*cube%dh(3,dir)-cube%origin(3))**2)
+      r=sqrt((real(i-1,KIND=dp)*cube%dh(1,dir)-cube%origin(1))**2&
+               +(real(i-1,KIND=dp)*cube%dh(2,dir)-cube%origin(2))**2+&
+                (real(i-1,KIND=dp)*cube%dh(3,dir)-cube%origin(3))**2)
       IF(r*au2a>=height) THEN
         index_plane = i
         EXIT
@@ -728,16 +747,16 @@ CONTAINS
 
        IF(dir==3)THEN
          val = (cube%grid(i,j,index_plane-1)+cube%grid(i,j,index_plane))*0.5D0
-         r1 = real(i-1)*cube%dh(1,1)+real(j-1)*cube%dh(1,2)+real(index_plane-1)*cube%dh(1,3)
-         r2 = real(i-1)*cube%dh(2,1)+real(j-1)*cube%dh(2,2)+real(index_plane-1)*cube%dh(2,3)
+         r1 = real(i-1,KIND=dp)*cube%dh(1,1)+real(j-1,KIND=dp)*cube%dh(1,2)+real(index_plane-1,KIND=dp)*cube%dh(1,3)
+         r2 = real(i-1,KIND=dp)*cube%dh(2,1)+real(j-1,KIND=dp)*cube%dh(2,2)+real(index_plane-1,KIND=dp)*cube%dh(2,3)
        ELSEIF(dir==1) THEN
          val = (cube%grid(index_plane-1,i,j)+cube%grid(index_plane,i,j))*0.5D0
-         r1 = real(index_plane-1)*cube%dh(2,1)+real(i-1)*cube%dh(2,2)+real(j-1)*cube%dh(2,3)
-         r2 = real(index_plane-1)*cube%dh(3,1)+real(i-1)*cube%dh(3,2)+real(j-1)*cube%dh(3,3)
+         r1 = real(index_plane-1,KIND=dp)*cube%dh(2,1)+real(i-1,KIND=dp)*cube%dh(2,2)+real(j-1,KIND=dp)*cube%dh(2,3)
+         r2 = real(index_plane-1,KIND=dp)*cube%dh(3,1)+real(i-1,KIND=dp)*cube%dh(3,2)+real(j-1,KIND=dp)*cube%dh(3,3)
        ELSEIF(dir==2) THEN
          val = (cube%grid(i,index_plane-1,j)+cube%grid(i,index_plane,j))*0.5D0
-         r1 = real(i-1)*cube%dh(1,1)+real(index_plane-1)*cube%dh(1,2)+real(j-1)*cube%dh(1,3)
-         r2 = real(i-1)*cube%dh(3,1)+real(index_plane-1)*cube%dh(3,2)+real(j-1)*cube%dh(3,3)
+         r1 = real(i-1,KIND=dp)*cube%dh(1,1)+real(index_plane-1,KIND=dp)*cube%dh(1,2)+real(j-1,KIND=dp)*cube%dh(1,3)
+         r2 = real(i-1,KIND=dp)*cube%dh(3,1)+real(index_plane-1,KIND=dp)*cube%dh(3,2)+real(j-1,KIND=dp)*cube%dh(3,3)
        END IF
 
        WRITE(101,*) r1*au2a, r2*au2a, val 
@@ -748,27 +767,30 @@ CONTAINS
   END SUBROUTINE compute_slice
 
   SUBROUTINE compute_iso_surf(cube,dir,iso_val_inp,h_min, h_max, grid_delta, &
-                   use_espot, iso_current, bwidth, cube_espot)
+                   use_espot, iso_current, from_top, check_atom_from_down, bwidth, cube_espot)
 
    TYPE(cube_type), POINTER :: cube
    INTEGER, INTENT(IN) ::dir
-   REAL, INTENT(IN) :: iso_val_inp, h_min, h_max, grid_delta
+   REAL(KIND=dp), INTENT(IN) :: iso_val_inp, h_min, h_max, grid_delta
    LOGICAL :: use_espot, iso_current
-   REAL, INTENT(IN), OPTIONAL ::  bwidth 
+   LOGICAL :: check_atom_from_down,  from_top
+   REAL(KIND=dp), INTENT(IN), OPTIONAL ::  bwidth 
    TYPE(cube_type), OPTIONAL, POINTER :: cube_espot
 
    CHARACTER(LEN=80) :: filename
-   LOGICAL :: check_atom_from_down, found_val
+   LOGICAL :: found_val
    INTEGER ::  d1,d2, iold, jold, kold
    INTEGER :: i, iat, ipoint, j,k, kval, index_min, index_max
-   REAL :: d12, iso_val
-   REAL :: alpha, fac1, fac2, r, r1, r2 , val1, val2, val1_e, val2_e
-   REAL, ALLOCATABLE, DIMENSION(:,:) :: ah
-   REAL, ALLOCATABLE, DIMENSION(:,:,:) :: data_grid
-   REAL :: delta, det, height, L1, L2, r1_shift, r2_shift, tmp
+   INTEGER :: i1,i2,incr
+   REAL(KIND=dp) :: d12, iso_val
+   REAL(KIND=dp) :: alpha, fac1, fac2, r, r1, r2 , val1, val2, val1_e, val2_e
+   REAL(KIND=dp), ALLOCATABLE, DIMENSION(:,:) :: ah
+   REAL(KIND=dp), ALLOCATABLE, DIMENSION(:,:,:) :: data_grid
+   REAL(KIND=dp) :: delta, det, height, L1, L2, r1_shift, r2_shift, tmp
    INTEGER :: ii, jj, im, ip, jm, jp, np1, np2 
 
 
+   found_val = .false.
    d1=dir+1; if(d1>3) d1=1
    d2=dir-1; if(d2<1) d2=3
    IF(d1>d2)THEN
@@ -786,10 +808,10 @@ CONTAINS
      index_min = 1
    ELSE
      DO i = 1,cube%npoints(dir)
-!       r=sqrt((real(i-1)*cube%dh(1,dir)+cube%origin(1))**2&
-!               +(real(i-1)*cube%dh(2,dir)+cube%origin(2))**2+&
-!                (real(i-1)*cube%dh(3,dir)+cube%origin(3))**2)
-       r  = cube%origin(dir) + real(i-1)*cube%dh(dir,dir)
+!       r=sqrt((real(i-1,KIND=dp)*cube%dh(1,dir)+cube%origin(1))**2&
+!               +(real(i-1,KIND=dp)*cube%dh(2,dir)+cube%origin(2))**2+&
+!                (real(i-1,KIND=dp)*cube%dh(3,dir)+cube%origin(3))**2)
+       r  = cube%origin(dir) + real(i-1,KIND=dp)*cube%dh(dir,dir)
        IF(r*au2a>=h_min)THEN
          index_min = i-1
          EXIT
@@ -801,10 +823,12 @@ CONTAINS
      index_max = cube%npoints(dir) - 1
    ELSE
      DO i = index_min,cube%npoints(dir)
-!       r=sqrt((real(i-1)*cube%dh(1,dir)+cube%origin(1))**2&
-!               +(real(i-1)*cube%dh(2,dir)+cube%origin(2))**2+&
-!                (real(i-1)*cube%dh(3,dir)+cube%origin(3))**2)
-       r  = cube%origin(dir) + real(i-1)*cube%dh(dir,dir)
+!       r=sqrt((real(i-1,KIND=dp)*cube%dh(1,dir)+cube%origin(1))**2&
+!               +(real(i-1,KIND=dp)*cube%dh(2,dir)+cube%origin(2))**2+&
+!                (real(i-1,KIND=dp)*cube%dh(3,dir)+cube%origin(3))**2)
+       r  = cube%origin(dir) + real(i-1,KIND=dp)*cube%dh(dir,dir)
+!dbg
+!    write(*,*) index_min, i, r, r*au2a, h_max
        IF(r*au2a>=h_max)THEN
          index_max = i
          EXIT
@@ -813,14 +837,33 @@ CONTAINS
    END IF
    IF(index_max==cube%npoints(dir)) index_max = index_max-1
 
+  !dbg
+!    write(*,*) index_min, index_max,  h_min, h_max
+!   stop
+  !dbg
+   IF(from_top) THEN
+      i1=index_max
+      i2=index_min
+      incr=-1
+   ELSE
+      i1=index_min
+      i2=index_max
+      incr=1
+   END IF
    IF(iso_current) THEN
      alpha = 2.D0*0.5123D0*bwidth*sqrt(au2ev)
      i = cube%npoints(d1)/2
      j = cube%npoints(d2)/2
-     DO k = index_min, index_max
+!dbg
+!  write(*,*) 'center grid ', i, j, ' k range ', i1,i2, incr
+!dbg
+     DO k = i1,i2,incr
        IF(dir==3)THEN
          val1 = cube%grid(i,j,k)
          val2 = cube%grid(i,j,k+1)
+!dbg
+!  write(*,*) 'cube ', i,j,k, val1, val2
+!dbg
        ELSEIF(dir==2)THEN
          val1 = cube%grid(i,k,j)
          val2 = cube%grid(i,k+1,j)
@@ -842,6 +885,9 @@ CONTAINS
            END IF
        END IF
        IF(found_val) THEN
+!dbg
+! write(*,*) 'found val ', val1, val2, ' at k ', k, ' weights ', fac1, fac2  
+!dbg
          IF(dir==3)THEN
            val1_e = cube_espot%grid(i,j,k) 
            val2_e = cube_espot%grid(i,j,k+1)
@@ -854,6 +900,10 @@ CONTAINS
          END IF 
          iso_val = fac1*(val1*exp(alpha*sqrt(val1_e))) + &
                    fac2*(val2*exp(alpha*sqrt(val2_e)))
+!dbg
+!  write(*,*) 'iso val ', iso_val, ' with espot ', val1_e, val2_e
+!  stop
+!dbg
          EXIT
        END IF
      END DO
@@ -869,7 +919,6 @@ CONTAINS
    write(*,*) ' Start search for iso surface at value ', iso_val, ' in the height range between ', h_min, ' and ', h_max
    write(*,*) ' Number of considered planes ', index_max-index_min + 1
 
-   check_atom_from_down = .true.
    IF(check_atom_from_down) THEN
      allocate(ah(cube%npoints(d1),cube%npoints(d2)))
      ah=h_max/au2a
@@ -883,8 +932,8 @@ CONTAINS
 !dbg
      DO i = 1,cube%npoints(d1)
        DO j = 1,cube%npoints(d2)
-         r1 = real(i-1)*cube%dh(1,d1)+cube%origin(1)+real(j-1)*cube%dh(1,d2)
-         r2 = real(i-1)*cube%dh(2,d1)+real(j-1)*cube%dh(2,d2)+cube%origin(2)
+         r1 = real(i-1,KIND=dp)*cube%dh(1,d1)+cube%origin(1)+real(j-1,KIND=dp)*cube%dh(1,d2)
+         r2 = real(i-1,KIND=dp)*cube%dh(2,d1)+real(j-1,KIND=dp)*cube%dh(2,d2)+cube%origin(2)
          DO iat = 1,cube%natom
            if(cube%coords(dir,iat)*au2a<h_max) THEN
              d12=sqrt((cube%coords(d1,iat)-r1)**2+(cube%coords(d2,iat)-r2)**2)
@@ -910,7 +959,7 @@ CONTAINS
      DO j = 1,cube%npoints(d2)
 !     DO j = cube%npoints(d2),1,-1 !cube%npoints(d2)
        found_val = .FALSE. 
-       DO k = index_min, index_max
+       DO k = i1,i2,incr
          IF(dir==3)THEN
            val1 = cube%grid(i,j,k)
            val2 = cube%grid(i,j,k+1)
@@ -950,8 +999,8 @@ CONTAINS
              END IF
          END IF
          IF(found_val) THEN
-             r  = cube%origin(dir) + real(i-1)*cube%dh(dir,d1)+real(j-1)*cube%dh(dir,d2)&
-               +real(k-1)*cube%dh(dir,dir)*fac1+real(k)*cube%dh(dir,dir)*fac2
+             r  = cube%origin(dir) + real(i-1,KIND=dp)*cube%dh(dir,d1)+real(j-1,KIND=dp)*cube%dh(dir,d2)&
+               +real(k-1,KIND=dp)*cube%dh(dir,dir)*fac1+real(k,KIND=dp)*cube%dh(dir,dir)*fac2
              IF(check_atom_from_down) THEN
                  if(r>ah(i,j)) THEN
                    write(*,'(A,2F10.5,A,F16.8,A, F16.8)') ' At ', r1*au2a, r2*au2a, 'tip goes behind atoms, position moved from ', &
@@ -966,15 +1015,15 @@ CONTAINS
              ELSE
                kval = k
              END IF
-             r1 = cube%origin(d1) + real(i-1)*cube%dh(d1,d1) +real(j-1)*cube%dh(d1,d2) &
-                +real(k-1)*cube%dh(d1,dir) *fac1+real(k)*cube%dh(d1,dir)*fac2
-             r2 = cube%origin(d2) + real(i-1)*cube%dh(d2,d1) +real(j-1)*cube%dh(d2,d2) &
-                +real(kval-1)*cube%dh(d2,dir) *fac1+real(kval)*cube%dh(d2,dir)*fac2
+             r1 = cube%origin(d1) + real(i-1,KIND=dp)*cube%dh(d1,d1) +real(j-1,KIND=dp)*cube%dh(d1,d2) &
+                +real(k-1,KIND=dp)*cube%dh(d1,dir) *fac1+real(k,KIND=dp)*cube%dh(d1,dir)*fac2
+             r2 = cube%origin(d2) + real(i-1,KIND=dp)*cube%dh(d2,d1) +real(j-1,KIND=dp)*cube%dh(d2,d2) &
+                +real(kval-1,KIND=dp)*cube%dh(d2,dir) *fac1+real(kval,KIND=dp)*cube%dh(d2,dir)*fac2
              data_grid(1,i,j) = r1
              data_grid(2,i,j) = r2
              IF(use_espot) THEN
                IF(dir==3)THEN
-                 data_grid(3,i,j) = (cube_espot%grid(i,j,kval)*fac1+cube_espot%grid(i,j,kval+1)*fac2)!/2.0D0
+                 data_grid(3,i,j) = (cube_espot%grid(i,j,kval-20)*fac1+cube_espot%grid(i,j,kval+1-20)*fac2)!/2.0D0
                ELSEIF(dir==2)THEN
                  data_grid(3,i,j) = (cube_espot%grid(i,kval,j)+cube_espot%grid(i,kval+1,j))/2.0D0
                ELSEIF(dir==1) THEN
@@ -991,10 +1040,10 @@ CONTAINS
          END IF 
        END DO ! k
        IF(.NOT. found_val) THEN
-          r1 = cube%origin(d1) + real(i-1)*cube%dh(d1,d1) +real(j-1)*cube%dh(d1,d2) &
-               +real(kold-1)*cube%dh(d1,dir)
-          r2 = cube%origin(d2) + real(i-1)*cube%dh(d2,d1) +real(j-1)*cube%dh(d2,d2) &
-               +real(kold-1)*cube%dh(d2,dir)
+          r1 = cube%origin(d1) + real(i-1,KIND=dp)*cube%dh(d1,d1) +real(j-1,KIND=dp)*cube%dh(d1,d2) &
+               +real(kold-1,KIND=dp)*cube%dh(d1,dir)
+          r2 = cube%origin(d2) + real(i-1,KIND=dp)*cube%dh(d2,d1) +real(j-1,KIND=dp)*cube%dh(d2,d2) &
+               +real(kold-1,KIND=dp)*cube%dh(d2,dir)
           r = data_grid(3,iold,jold)
           data_grid(1,i,j) = r1
           data_grid(2,i,j) = r2
@@ -1039,37 +1088,44 @@ CONTAINS
    delta = grid_delta
 
    np1 = INT(L1/delta) + 1
-   np2 = INT(L2/delta) + 1
+   np2 = INT(2.0D0*L2/delta) + 1
 
    det = (cube%dh(d1,d1)*cube%dh(d2,d2) - cube%dh(d1,d2)*cube%dh(d2,d1))
    det = 1.0D0/det
    DO ii = 1,np1
-     r1 = delta*real(ii-1)
+     r1 = delta*real(ii-1,KIND=dp)
      DO jj = 1,np2
-       r2 = delta*real(jj-1)
+       r2 = delta*real(jj-1,KIND=dp)
        tmp = (cube%dh(d2,d2)*r1-cube%dh(d1,d2)*r2)*det
        i = int(tmp)+1
        tmp = (cube%dh(d1,d1)*r2-cube%dh(d2,d1)*r1)*det
        j = int(tmp)+1
        IF(i<1) THEN
-        r1_shift = r1+cube%npoints(d1)*cube%dh(d1,d1)
-        r2_shift = r2+cube%npoints(d1)*cube%dh(d2,d1)
-        tmp = (cube%dh(d2,d2)*r1_shift-cube%dh(d1,d2)*r2_shift)*det
-        i = int(tmp)+1
-        tmp = (cube%dh(d1,d1)*r2_shift-cube%dh(d2,d1)*r1_shift)*det
-        j = int(tmp)+1
+         r1_shift = r1+cube%npoints(d1)*cube%dh(d1,d1)
+         r2_shift = r2+cube%npoints(d1)*cube%dh(d2,d1)
+         tmp = (cube%dh(d2,d2)*r1_shift-cube%dh(d1,d2)*r2_shift)*det
+         i = int(tmp)+1
+!        tmp = (cube%dh(d1,d1)*r2_shift-cube%dh(d2,d1)*r1_shift)*det
+!        j = int(tmp)+1
        ELSEIF(i>cube%npoints(d1)) THEN
-        r1_shift = r1-cube%npoints(d1)*cube%dh(d1,d1)
-        r2_shift = r2-cube%npoints(d1)*cube%dh(d2,d1)
-        tmp = (cube%dh(d2,d2)*r1_shift-cube%dh(d1,d2)*r2_shift)*det
-        i = int(tmp)+1
-        tmp = (cube%dh(d1,d1)*r2_shift-cube%dh(d2,d1)*r1_shift)*det
-        j = int(tmp)+1
+         r1_shift = r1-cube%npoints(d1)*cube%dh(d1,d1)
+         r2_shift = r2-cube%npoints(d1)*cube%dh(d2,d1)
+         tmp = (cube%dh(d2,d2)*r1_shift-cube%dh(d1,d2)*r2_shift)*det
+         i = int(tmp)+1
+!        tmp = (cube%dh(d1,d1)*r2_shift-cube%dh(d2,d1)*r1_shift)*det
+!        j = int(tmp)+1
        END IF
 
        IF(j<1) THEN
-
+         r1_shift = r1+cube%npoints(d2)*cube%dh(d1,d2)
+         r2_shift = r2+cube%npoints(d2)*cube%dh(d2,d2)
+         tmp = (cube%dh(d1,d1)*r2_shift-cube%dh(d2,d1)*r1_shift)*det
+         j = int(tmp)+1
        ELSEIF(j>cube%npoints(d2)) THEN
+         r1_shift = r1-cube%npoints(d2)*cube%dh(d1,d2)
+         r2_shift = r2-cube%npoints(d2)*cube%dh(d2,d2)
+         tmp = (cube%dh(d1,d1)*r2_shift-cube%dh(d2,d1)*r1_shift)*det
+         j = int(tmp)+1
        END IF
 
        im = i 
@@ -1131,8 +1187,8 @@ PROGRAM main
    INTEGER :: iunit_cube_in,iunit_cube_out,iunit_xyz,narg
    INTEGER :: dir
    LOGICAL :: did_something
-   REAL :: height, iso_val
-   REAL, DIMENSION(3) :: center
+   REAL(KIND=dp) :: height, iso_val
+   REAL(KIND=dp), DIMENSION(3) :: center
    TYPE(input_type) :: input
   
    CALL init_input(input)
@@ -1280,10 +1336,10 @@ PROGRAM main
                 dir, ' at level ', iso_val 
         IF(input%espot_over_iso .OR. input%iso_current ) THEN
             CALL compute_iso_surf(cube, dir, iso_val, input%iso_hmin ,input%iso_hmax, input%iso_delta_grid,&
-                  input%espot_over_iso,  input%iso_current, input%bwidth,  cube_espot)
+                  input%espot_over_iso,  input%iso_current, input%from_top, input%check_atom_from_down, input%bwidth,  cube_espot)
         ELSE
             CALL compute_iso_surf(cube, dir, iso_val, input%iso_hmin ,input%iso_hmax, input%iso_delta_grid, &
-                use_espot=.FALSE., iso_current=.FALSE.)
+                use_espot=.FALSE., iso_current=.FALSE., from_top=input%from_top, check_atom_from_down=input%check_atom_from_down)
         END IF
         write(6,*) "Done"
      END IF
