@@ -27,8 +27,7 @@ def main() -> None:
             f.write(toolchain_full(target_cpu="generic") + regtest(version))
 
     with OutputFile(f"Dockerfile.test_openmpi-psmp", args.check) as f:
-        # Also testing --with-gcc=install here, see github.com/cp2k/cp2k/issues/2062 .
-        f.write(toolchain_full(mpi_mode="openmpi", with_gcc="install"))
+        f.write(toolchain_full(mpi_mode="openmpi"))
         f.write(regtest("psmp"))
 
     with OutputFile(f"Dockerfile.test_fedora-psmp", args.check) as f:
@@ -46,7 +45,7 @@ def main() -> None:
     with OutputFile(f"Dockerfile.test_minimal", args.check) as f:
         f.write(toolchain_ubuntu_nompi() + regtest_cmake("minimal", "ssmp"))
 
-    with OutputFile(f"Dockerfile.test_cmake", args.check) as f:
+    with OutputFile(f"Dockerfile.test_spack", args.check) as f:
         f.write(spack_env_toolchain() + regtest_cmake("spack", "psmp"))
 
     for version in "ssmp", "psmp":
@@ -57,7 +56,7 @@ def main() -> None:
         with OutputFile(f"Dockerfile.test_coverage-{version}", args.check) as f:
             f.write(toolchain_full() + coverage(version))
 
-    for gcc_version in 8, 9, 10, 11, 12, 13:
+    for gcc_version in 8, 9, 10, 11, 12, 13, 14:
         with OutputFile(f"Dockerfile.test_gcc{gcc_version}", args.check) as f:
             if gcc_version > 8:
                 f.write(toolchain_ubuntu_nompi(gcc_version=gcc_version))
@@ -79,7 +78,6 @@ def main() -> None:
         f.write(
             toolchain_full(
                 base_image="arm64v8/ubuntu:24.04",
-                with_libxsmm="no",
                 with_libtorch="no",
                 with_deepmd="no",
             )
@@ -427,7 +425,16 @@ def toolchain_ubuntu_nompi(
     assert gcc_version > 8
     output = rf"""
 FROM {base_image}
+"""
 
+    if gcc_version > 13:
+        output += rf"""
+# Add Ubuntu universe repository.
+RUN apt-get update -qq && apt-get install -qq --no-install-recommends software-properties-common
+RUN add-apt-repository universe
+"""
+
+    output += rf"""
 # Install Ubuntu packages.
 RUN export DEBIAN_FRONTEND=noninteractive DEBCONF_NONINTERACTIVE_SEEN=true && \
     apt-get update -qq && apt-get install -qq --no-install-recommends \
@@ -508,7 +515,7 @@ RUN ln -sf /usr/bin/gcc-{gcc_version}      /usr/local/bin/gcc  && \
 # ======================================================================================
 def toolchain_intel() -> str:
     return rf"""
-FROM intel/hpckit:2024.2.0-1-devel-ubuntu22.04
+FROM intel/hpckit:2024.2.1-0-devel-ubuntu22.04
 
 """ + install_toolchain(
         base_image="ubuntu",
@@ -833,9 +840,10 @@ RUN apt-get update -qq && apt-get install -qq --no-install-recommends \
 
 # Install a recent developer version of Spack.
 WORKDIR /opt/spack
+ARG SPACK_VERSION=501ee68606405ea2ac26d369a5139d75be88dac8
 RUN git init --quiet && \
     git remote add origin https://github.com/spack/spack.git && \
-    git fetch --quiet --depth 1 origin tag develop-2024-05-26 --no-tags && \
+    git fetch --quiet --depth 1 origin ${{SPACK_VERSION}} --no-tags && \
     git checkout --quiet FETCH_HEAD
 ENV PATH="/opt/spack/bin:${{PATH}}"
 
@@ -843,6 +851,13 @@ ENV PATH="/opt/spack/bin:${{PATH}}"
 RUN spack compiler find
 RUN spack external find --all --not-buildable
 
+# Enable Spack build cache
+ARG SPACK_BUILD_CACHE=develop-2024-12-15
+RUN spack mirror add ${{SPACK_BUILD_CACHE}} https://binaries.spack.io/${{SPACK_BUILD_CACHE}} && \
+    spack mirror add develop https://binaries.spack.io/develop && \
+    spack buildcache keys --install --trust --force && \
+    spack mirror rm develop
+
 # Install CP2K's dependencies via Spack.
 WORKDIR /
 COPY ./tools/spack/cp2k-dependencies.yaml .
