@@ -26,10 +26,16 @@ apt-get install -qq --no-install-recommends \
   default-jre-headless \
   libsaxonhe-java \
   python3 \
-  python3-pip
+  python3-pip \
+  python3-venv
 rm -rf /var/lib/apt/lists/*
 
-pip3 install --quiet sphinx myst-parser sphinx_rtd_theme lxml
+# Create and activate a virtual environment for Python packages.
+python3 -m venv /opt/venv
+export PATH="/opt/venv/bin:$PATH"
+
+# install python packages
+pip3 install -r /opt/cp2k/docs/requirements.txt
 
 echo -e "\n========== Generating Manual =========="
 
@@ -42,7 +48,7 @@ cd /workspace/artifacts/manual
 set +e # disable error trapping for remainder of script
 (
   set -e # abort if error is encountered
-  /opt/cp2k/docs/generate_input_reference.py ./cp2k_input.xml ./references.html
+  /opt/cp2k/docs/generate_input_reference.py ./cp2k_input.xml
   echo ""
   sphinx-build /opt/cp2k/docs/ /workspace/artifacts/manual -W -n --keep-going --jobs 16
   /opt/cp2k/docs/fix_github_links.py /workspace/artifacts/manual
