@@ -33,9 +33,6 @@ export OMP_STACKSIZE=64m
 # Improve code coverage on COSMA.
 export COSMA_DIM_THRESHOLD=0
 
-# Bind pika threads to first two cores. This is a hack. Do not use for production!
-export PIKA_PROCESS_MASK="0x3"
-
 # Load Spack or Toolchain environment.
 if [[ "${PROFILE}" == "spack" ]]; then
   eval "$(spack env activate myenv --sh)"
@@ -48,7 +45,7 @@ fi
 echo -e "\n========== Running Regtests =========="
 set -x
 # shellcheck disable=SC2086
-./tests/do_regtest.py local ${VERSION} ${TESTOPTS}
+./tests/do_regtest.py ./build/bin/ ${VERSION} ${TESTOPTS}
 
 exit 0 # Prevent CI from overwriting do_regtest's summary message.
 
