@@ -84,8 +84,11 @@ case "$with_scalapack" in
 esac
 if [ "$with_scalapack" != "__DONTUSE__" ]; then
   SCALAPACK_LIBS="-lscalapack"
+  cat << EOF > "${BUILDDIR}/setup_scalapack"
+export SCALAPACK_VER="${scalapack_ver}"
+EOF
   if [ "$with_scalapack" != "__SYSTEM__" ]; then
-    cat << EOF > "${BUILDDIR}/setup_scalapack"
+    cat << EOF >> "${BUILDDIR}/setup_scalapack"
 prepend_path LD_LIBRARY_PATH "${pkg_install_dir}/lib"
 prepend_path LD_RUN_PATH "${pkg_install_dir}/lib"
 prepend_path LIBRARY_PATH "${pkg_install_dir}/lib"
